@@ -13,7 +13,7 @@ Usage::
 """
 import sys
 from datetime import datetime
-from typing import Any, Dict, List, Union
+from typing import Any, Dict, List, Mapping, Sequence, Union
 
 from .literals import (
     EncryptionStatusType,
@@ -106,7 +106,7 @@ _RequiredCreateLedgerRequestRequestTypeDef = TypedDict(
 _OptionalCreateLedgerRequestRequestTypeDef = TypedDict(
     "_OptionalCreateLedgerRequestRequestTypeDef",
     {
-        "Tags": Dict[str, str],
+        "Tags": Mapping[str, str],
         "DeletionProtection": bool,
         "KmsKey": str,
     },
@@ -558,7 +558,7 @@ _RequiredStreamJournalToKinesisRequestRequestTypeDef = TypedDict(
 _OptionalStreamJournalToKinesisRequestRequestTypeDef = TypedDict(
     "_OptionalStreamJournalToKinesisRequestRequestTypeDef",
     {
-        "Tags": Dict[str, str],
+        "Tags": Mapping[str, str],
         "ExclusiveEndTime": Union[datetime, str],
     },
     total=False,
@@ -584,7 +584,7 @@ TagResourceRequestRequestTypeDef = TypedDict(
     "TagResourceRequestRequestTypeDef",
     {
         "ResourceArn": str,
-        "Tags": Dict[str, str],
+        "Tags": Mapping[str, str],
     },
 )
 
@@ -592,7 +592,7 @@ UntagResourceRequestRequestTypeDef = TypedDict(
     "UntagResourceRequestRequestTypeDef",
     {
         "ResourceArn": str,
-        "TagKeys": List[str],
+        "TagKeys": Sequence[str],
     },
 )
 
